@@ -231,7 +231,7 @@ static void
 add_message_to_cache (CamelMapiFolder *mapi_folder, const gchar *uid, CamelMimeMessage **msg, GCancellable *cancellable)
 {
 	CamelFolder *folder;
-	CamelStream *cache_stream;
+	GIOStream *base_stream;
 
 	g_return_if_fail (mapi_folder != NULL);
 	g_return_if_fail (msg != NULL);
@@ -242,7 +242,13 @@ add_message_to_cache (CamelMapiFolder *mapi_folder, const gchar *uid, CamelMimeM
 
 	camel_folder_summary_lock (folder->summary);
 
-	if ((cache_stream = camel_data_cache_add (mapi_folder->cache, "cache", uid, NULL))) {
+	base_stream = camel_data_cache_add (mapi_folder->cache, "cache", uid, NULL);
+	if (base_stream != NULL) {
+		CamelStream *cache_stream;
+
+		cache_stream = camel_stream_new (base_stream);
+		g_object_unref (base_stream);
+
 		if (camel_data_wrapper_write_to_stream_sync ((CamelDataWrapper *) (*msg), cache_stream, cancellable, NULL) == -1
 		    || camel_stream_flush (cache_stream, cancellable, NULL) == -1) {
 			camel_data_cache_remove (mapi_folder->cache, "cache", uid, NULL);
@@ -599,6 +605,7 @@ gather_object_summary_cb (EMapiConnection *conn,
 	const gchar *transport_headers;
 	CamelMessageInfo *info;
 	gboolean is_new = FALSE;
+	gboolean user_has_read;
 
 	g_return_val_if_fail (gos != NULL, FALSE);
 	g_return_val_if_fail (gos->folder != NULL, FALSE);
@@ -642,9 +649,9 @@ gather_object_summary_cb (EMapiConnection *conn,
 			if (camel_mime_part_construct_from_parser_sync (part, parser, NULL, NULL)) {
 				info = camel_folder_summary_info_new_from_header (gos->folder->summary, part->headers);
 				if (info) {
-					CamelMapiMessageInfo *minfo = (CamelMapiMessageInfo *) info;
 					const uint32_t *msg_size;
 
+					minfo = (CamelMapiMessageInfo *) info;
 					minfo->info.uid = camel_pstring_strdup (uid_str);
 
 					msg_size = e_mapi_util_find_array_propval (&object->properties, PidTagMessageSize);
@@ -682,11 +689,6 @@ gather_object_summary_cb (EMapiConnection *conn,
 			minfo->info.date_received = e_mapi_util_filetime_to_time_t (delivery_time);
 			minfo->info.size = msg_size ? *msg_size : 0;
 
-			if (minfo->info.date_sent != 0)
-				minfo->info.date_sent = minfo->info.date_sent;
-			if (minfo->info.date_received != 0)
-				minfo->info.date_received = minfo->info.date_received;
-
 			/* Threading related properties */
 			mapi_set_message_id (minfo, message_id);
 			if (references || in_reply_to)
@@ -741,32 +743,28 @@ gather_object_summary_cb (EMapiConnection *conn,
 		}
 
 		minfo = (CamelMapiMessageInfo *) info;
-		if (minfo) {
-			if (minfo->info.date_sent == 0)
-				minfo->info.date_sent = minfo->info.date_received;
-			if (minfo->info.date_received == 0)
-				minfo->info.date_received = minfo->info.date_sent;
-		}
+		if (minfo->info.date_sent == 0)
+			minfo->info.date_sent = minfo->info.date_received;
+		if (minfo->info.date_received == 0)
+			minfo->info.date_received = minfo->info.date_sent;
 	}
 
-	if (info) {
-		gboolean user_has_read = (camel_message_info_flags (info) & CAMEL_MESSAGE_SEEN) != 0;
+	user_has_read = (camel_message_info_flags (info) & CAMEL_MESSAGE_SEEN) != 0;
 
-		update_message_info (info, object, is_new, gos->is_public_folder, user_has_read);
+	update_message_info (info, object, is_new, gos->is_public_folder, user_has_read);
 
-		if (is_new) {
-			camel_folder_summary_add (gos->folder->summary, info);
-			camel_folder_change_info_add_uid (gos->changes, camel_message_info_uid (info));
-			camel_folder_change_info_recent_uid (gos->changes, camel_message_info_uid (info));
+	if (is_new) {
+		camel_folder_summary_add (gos->folder->summary, info);
+		camel_folder_change_info_add_uid (gos->changes, camel_message_info_uid (info));
+		camel_folder_change_info_recent_uid (gos->changes, camel_message_info_uid (info));
 
-			camel_message_info_ref (info);
-		} else {
-			camel_folder_change_info_change_uid (gos->changes, camel_message_info_uid (info));
-		}
-
-		camel_message_info_unref (info);
+		camel_message_info_ref (info);
+	} else {
+		camel_folder_change_info_change_uid (gos->changes, camel_message_info_uid (info));
 	}
 
+	camel_message_info_unref (info);
+
 	if (obj_total > 0)
 		camel_operation_progress (cancellable, obj_index * 100 / obj_total);
 
@@ -1161,6 +1159,9 @@ mapi_folder_constructed (GObject *object)
 	gchar *host;
 	gchar *user;
 
+	/* Chain up to parent's method. */
+	G_OBJECT_CLASS (camel_mapi_folder_parent_class)->constructed (object);
+
 	folder = CAMEL_FOLDER (object);
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
@@ -1459,18 +1460,24 @@ mapi_folder_get_message_cached (CamelFolder *folder,
 {
 	CamelMapiFolder *mapi_folder;
 	CamelMimeMessage *msg = NULL;
-	CamelStream *stream, *cache_stream;
+	CamelStream *stream;
+	GIOStream *base_stream;
 
 	mapi_folder = CAMEL_MAPI_FOLDER (folder);
 
 	if (!camel_folder_summary_check_uid (folder->summary, message_uid))
 		return NULL;
 
-	cache_stream  = camel_data_cache_get (mapi_folder->cache, "cache", message_uid, NULL);
 	stream = camel_stream_mem_new ();
-	if (cache_stream) {
+
+	base_stream = camel_data_cache_get (mapi_folder->cache, "cache", message_uid, NULL);
+	if (base_stream != NULL) {
+		CamelStream *cache_stream;
 		GError *local_error = NULL;
 
+		cache_stream = camel_stream_new (base_stream);
+		g_object_unref (base_stream);
+
 		msg = camel_mime_message_new ();
 
 		g_seekable_seek (G_SEEKABLE (stream), 0, G_SEEK_SET, NULL, NULL);
